@@ -28,5 +28,8 @@ test_pipeline = [
     dict(
         type='Collect',
         keys=['img'],
-        meta_keys=['filename', 'resize_shape', 'valid_ratio']),
+        meta_keys=[
+            'filename', 'resize_shape', 'valid_ratio', 'img_norm_cfg',
+            'ori_filename', 'img_shape', 'ori_shape'
+        ]),
 ]
