@@ -36,7 +36,8 @@ test_pipeline = [
                 type='Collect',
                 keys=['img'],
                 meta_keys=[
-                    'filename', 'ori_shape', 'resize_shape', 'valid_ratio'
+                    'filename', 'ori_shape', 'resize_shape', 'valid_ratio',
+                    'img_norm_cfg', 'ori_filename', 'img_shape'
                 ]),
         ])
 ]
