@@ -1,6 +1,7 @@
+# Copyright (c) OpenMMLab. All rights reserved.
 from . import evaluation
 from .mask import extract_boundary, points2boundary, seg2boundary
-from .visualize import (det_recog_show_result, imshow_edge_node,
+from .visualize import (det_recog_show_result, imshow_edge, imshow_node,
                         imshow_pred_boundary, imshow_text_char_boundary,
                         imshow_text_label, overlay_mask_img, show_feature,
                         show_img_boundary, show_pred_gt)
@@ -11,6 +12,6 @@ __all__ = [
     'points2boundary', 'seg2boundary', 'extract_boundary', 'overlay_mask_img',
     'show_feature', 'show_img_boundary', 'show_pred_gt',
     'imshow_pred_boundary', 'imshow_text_char_boundary', 'imshow_text_label',
-    'imshow_edge_node', 'det_recog_show_result'
+    'imshow_node', 'det_recog_show_result', 'imshow_edge'
 ]
 __all__ += evaluation.__all__
