@@ -1,9 +1,10 @@
+# Copyright (c) OpenMMLab. All rights reserved.
 import numpy as np
-from pycocotools.coco import COCO
-
-import mmocr.utils as utils
+from mmdet.datasets.api_wrappers import COCO
 from mmdet.datasets.builder import DATASETS
 from mmdet.datasets.coco import CocoDataset
+
+import mmocr.utils as utils
 from mmocr.core.evaluation.hmean import eval_hmean
 
 
