@@ -1,3 +1,4 @@
+# Copyright (c) OpenMMLab. All rights reserved.
 from .db_head import DBHead
 from .drrg_head import DRRGHead
 from .fce_head import FCEHead
@@ -7,6 +8,6 @@ from .pse_head import PSEHead
 from .textsnake_head import TextSnakeHead
 
 __all__ = [
-    'PSEHead', 'PANHead', 'DBHead', 'FCEHead', 'HeadMixin', 'TextSnakeHead',
-    'DRRGHead'
+    'PSEHead', 'PANHead', 'DBHead', 'FCEHead', 'TextSnakeHead', 'DRRGHead',
+    'HeadMixin'
 ]
