@@ -1,4 +1,5 @@
-from mmdet.models.builder import DETECTORS
+# Copyright (c) OpenMMLab. All rights reserved.
+from mmocr.models.builder import DETECTORS
 from .single_stage_text_detector import SingleStageTextDetector
 from .text_detector_mixin import TextDetectorMixin
 
@@ -19,9 +20,11 @@ class FCENet(TextDetectorMixin, SingleStageTextDetector):
                  train_cfg=None,
                  test_cfg=None,
                  pretrained=None,
-                 show_score=False):
+                 show_score=False,
+                 init_cfg=None):
         SingleStageTextDetector.__init__(self, backbone, neck, bbox_head,
-                                         train_cfg, test_cfg, pretrained)
+                                         train_cfg, test_cfg, pretrained,
+                                         init_cfg)
         TextDetectorMixin.__init__(self, show_score)
 
     def simple_test(self, img, img_metas, rescale=False):
