@@ -1,14 +1,12 @@
-import torch.nn as nn
+# Copyright (c) OpenMMLab. All rights reserved.
+from mmcv.runner import BaseModule
 
 from mmocr.models.builder import PREPROCESSOR
 
 
 @PREPROCESSOR.register_module()
-class BasePreprocessor(nn.Module):
+class BasePreprocessor(BaseModule):
     """Base Preprocessor class for text recognition."""
 
-    def init_weights(self):
-        pass
-
     def forward(self, x, **kwargs):
         return x
